{{-- CSS/JS の読み込み（1レスポンスにつき一度だけ）。config('rich-editor.inject_assets')=false で無効化し、
     自前で @vite やレイアウトから読み込むこともできる。 --}}
@once
    @if (config('rich-editor.inject_assets', true))
        @php($__reBase = rtrim(config('rich-editor.asset_base', 'vendor/rich-editor'), '/'))
        <link rel="stylesheet" href="{{ asset($__reBase.'/rich-editor.css') }}">
        <script type="module" src="{{ asset($__reBase.'/rich-editor.js') }}"></script>
    @endif
@endonce
<textarea
    name="{{ $name }}"
    @if ($id) id="{{ $id }}" @endif
    data-rich-editor
    data-min-height="{{ $minHeight ?? config('rich-editor.min_height', '120px') }}"
    @if ($uploadUrl) data-upload-url="{{ $uploadUrl }}" @endif
    @if ($mentionsJson()) data-mention-users="{{ $mentionsJson() }}" @endif
    @if ($draftKey) data-draft-key="{{ $draftKey }}" @endif
    @unless ($drafts) data-no-draft @endunless
    @if ($compact) data-compact @endif
    placeholder="{{ $placeholder }}"
    {{ $attributes }}
>{{ $value }}</textarea>
